/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Substitute the type names.  */
#define YYSTYPE         VCD_STYPE
/* Substitute the variable and function names.  */
#define yyparse         vcd_parse
#define yylex           vcd_lex
#define yyerror         vcd_error
#define yydebug         vcd_debug
#define yynerrs         vcd_nerrs
#define yylval          vcd_lval
#define yychar          vcd_char

/* First part of user prologue.  */
#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"

/*
 * parse_vcd.y - parser for a VCD data file
 *
 * Copyright (C) 2005 Raimund Jacob <raimi@lkcc.org>
 * Copyright (C) 2006, 2008 Stefan Jahn <stefan@lkcc.org>
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
 * Boston, MA 02110-1301, USA.  
 *
 * $Id$
 *
 */

#if HAVE_CONFIG_H
# include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#define YYERROR_VERBOSE 42
#define YYDEBUG 1
#define YYMAXDEPTH 10000000

#include "check_vcd.h"


#line 122 "parse_vcd.cpp"

# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

#include "parse_vcd.hpp"
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_t_END = 3,                      /* t_END  */
  YYSYMBOL_t_COMMENT = 4,                  /* t_COMMENT  */
  YYSYMBOL_t_DATE = 5,                     /* t_DATE  */
  YYSYMBOL_t_ENDDEFINITIONS = 6,           /* t_ENDDEFINITIONS  */
  YYSYMBOL_t_SCOPE = 7,                    /* t_SCOPE  */
  YYSYMBOL_t_TIMESCALE = 8,                /* t_TIMESCALE  */
  YYSYMBOL_t_UPSCOPE = 9,                  /* t_UPSCOPE  */
  YYSYMBOL_t_VAR = 10,                     /* t_VAR  */
  YYSYMBOL_t_VERSION = 11,                 /* t_VERSION  */
  YYSYMBOL_t_DUMPALL = 12,                 /* t_DUMPALL  */
  YYSYMBOL_t_DUMPOFF = 13,                 /* t_DUMPOFF  */
  YYSYMBOL_t_DUMPON = 14,                  /* t_DUMPON  */
  YYSYMBOL_t_DUMPVARS = 15,                /* t_DUMPVARS  */
  YYSYMBOL_s_MODULE = 16,                  /* s_MODULE  */
  YYSYMBOL_s_TASK = 17,                    /* s_TASK  */
  YYSYMBOL_s_FUNCTION = 18,                /* s_FUNCTION  */
  YYSYMBOL_s_FORK = 19,                    /* s_FORK  */
  YYSYMBOL_s_BEGIN = 20,                   /* s_BEGIN  */
  YYSYMBOL_ONE = 21,                       /* ONE  */
  YYSYMBOL_B = 22,                         /* B  */
  YYSYMBOL_Z = 23,                         /* Z  */
  YYSYMBOL_ZERO = 24,                      /* ZERO  */
  YYSYMBOL_HASHMARK = 25,                  /* HASHMARK  */
  YYSYMBOL_U = 26,                         /* U  */
  YYSYMBOL_R = 27,                         /* R  */
  YYSYMBOL_TEN = 28,                       /* TEN  */
  YYSYMBOL_HUNDRET = 29,                   /* HUNDRET  */
  YYSYMBOL_PICO = 30,                      /* PICO  */
  YYSYMBOL_MICRO = 31,                     /* MICRO  */
  YYSYMBOL_NANO = 32,                      /* NANO  */
  YYSYMBOL_FEMTO = 33,                     /* FEMTO  */
  YYSYMBOL_SECOND = 34,                    /* SECOND  */
  YYSYMBOL_MILLI = 35,                     /* MILLI  */
  YYSYMBOL_EVENT = 36,                     /* EVENT  */
  YYSYMBOL_INTEGER = 37,                   /* INTEGER  */
  YYSYMBOL_PARAMETER = 38,                 /* PARAMETER  */
  YYSYMBOL_REAL = 39,                      /* REAL  */
  YYSYMBOL_REG = 40,                       /* REG  */
  YYSYMBOL_SUPPLY0 = 41,                   /* SUPPLY0  */
  YYSYMBOL_SUPPLY1 = 42,                   /* SUPPLY1  */
  YYSYMBOL_TIME = 43,                      /* TIME  */
  YYSYMBOL_TRI = 44,                       /* TRI  */
  YYSYMBOL_TRIAND = 45,                    /* TRIAND  */
  YYSYMBOL_TRIOR = 46,                     /* TRIOR  */
  YYSYMBOL_TRIREG = 47,                    /* TRIREG  */
  YYSYMBOL_TRI0 = 48,                      /* TRI0  */
  YYSYMBOL_TRI1 = 49,                      /* TRI1  */
  YYSYMBOL_WAND = 50,                      /* WAND  */
  YYSYMBOL_WIRE = 51,                      /* WIRE  */
  YYSYMBOL_WOR = 52,                       /* WOR  */
  YYSYMBOL_Real = 53,                      /* Real  */
  YYSYMBOL_Binary = 54,                    /* Binary  */
  YYSYMBOL_PositiveInteger = 55,           /* PositiveInteger  */
  YYSYMBOL_PositiveHugeInteger = 56,       /* PositiveHugeInteger  */
  YYSYMBOL_Identifier = 57,                /* Identifier  */
  YYSYMBOL_IdentifierCode = 58,            /* IdentifierCode  */
  YYSYMBOL_Reference = 59,                 /* Reference  */
  YYSYMBOL_InvalidCharacter = 60,          /* InvalidCharacter  */
  YYSYMBOL_61_ = 61,                       /* '['  */
  YYSYMBOL_62_ = 62,                       /* ']'  */
  YYSYMBOL_63_ = 63,                       /* ':'  */
  YYSYMBOL_64_ = 64,                       /* '('  */
  YYSYMBOL_65_ = 65,                       /* ')'  */
  YYSYMBOL_66_B_ = 66,                     /* 'B'  */
  YYSYMBOL_67_R_ = 67,                     /* 'R'  */
  YYSYMBOL_YYACCEPT = 68,                  /* $accept  */
  YYSYMBOL_ValueChangeDumpDefinitions = 69, /* ValueChangeDumpDefinitions  */
  YYSYMBOL_DeclarationList = 70,           /* DeclarationList  */
  YYSYMBOL_Declaration = 71,               /* Declaration  */
  YYSYMBOL_ScopeDeclaration = 72,          /* ScopeDeclaration  */
  YYSYMBOL_ScopeType = 73,                 /* ScopeType  */
  YYSYMBOL_TimeScaleDeclaration = 74,      /* TimeScaleDeclaration  */
  YYSYMBOL_TimeScale = 75,                 /* TimeScale  */
  YYSYMBOL_TimeUnit = 76,                  /* TimeUnit  */
  YYSYMBOL_VarDeclaration = 77,            /* VarDeclaration  */
  YYSYMBOL_BitSelect = 78,                 /* BitSelect  */
  YYSYMBOL_VarType = 79,                   /* VarType  */
  YYSYMBOL_Size = 80,                      /* Size  */
  YYSYMBOL_SimulationCommandList = 81,     /* SimulationCommandList  */
  YYSYMBOL_SimulationCommand = 82,         /* SimulationCommand  */
  YYSYMBOL_ValueChangeset = 83,            /* ValueChangeset  */
  YYSYMBOL_SimulationTime = 84,            /* SimulationTime  */
  YYSYMBOL_ValueChangeList = 85,           /* ValueChangeList  */
  YYSYMBOL_ValueChange = 86,               /* ValueChange  */
  YYSYMBOL_ScalarValueChange = 87,         /* ScalarValueChange  */
  YYSYMBOL_Value = 88,                     /* Value  */
  YYSYMBOL_VectorValueChange = 89          /* VectorValueChange  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;




#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int8 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if !defined yyoverflow

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* !defined yyoverflow */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined VCD_STYPE_IS_TRIVIAL && VCD_STYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  48
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   89

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  68
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  22
/* YYNRULES -- Number of rules.  */
#define YYNRULES  71
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  111

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   315


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_int8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      64,    65,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,    63,     2,
       2,     2,     2,     2,     2,     2,    66,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,    67,     2,     2,     2,     2,     2,     2,     2,
       2,    61,     2,    62,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60
};

#if VCD_DEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   108,   108,   111,   112,   116,   117,   118,   119,   135,
     136,   145,   146,   162,   170,   171,   172,   173,   174,   178,
     185,   186,   187,   191,   192,   193,   194,   195,   196,   200,
     210,   211,   216,   221,   229,   231,   233,   236,   238,   240,
     242,   244,   246,   248,   250,   252,   254,   256,   258,   260,
     262,   267,   270,   271,   275,   276,   277,   278,   281,   288,
     296,   301,   302,   308,   309,   313,   321,   322,   323,   324,
     328,   333
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if VCD_DEBUG || 0
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "t_END", "t_COMMENT",
  "t_DATE", "t_ENDDEFINITIONS", "t_SCOPE", "t_TIMESCALE", "t_UPSCOPE",
  "t_VAR", "t_VERSION", "t_DUMPALL", "t_DUMPOFF", "t_DUMPON", "t_DUMPVARS",
  "s_MODULE", "s_TASK", "s_FUNCTION", "s_FORK", "s_BEGIN", "ONE", "B", "Z",
  "ZERO", "HASHMARK", "U", "R", "TEN", "HUNDRET", "PICO", "MICRO", "NANO",
  "FEMTO", "SECOND", "MILLI", "EVENT", "INTEGER", "PARAMETER", "REAL",
  "REG", "SUPPLY0", "SUPPLY1", "TIME", "TRI", "TRIAND", "TRIOR", "TRIREG",
  "TRI0", "TRI1", "WAND", "WIRE", "WOR", "Real", "Binary",
  "PositiveInteger", "PositiveHugeInteger", "Identifier", "IdentifierCode",
  "Reference", "InvalidCharacter", "'['", "']'", "':'", "'('", "')'",
  "'B'", "'R'", "$accept", "ValueChangeDumpDefinitions", "DeclarationList",
  "Declaration", "ScopeDeclaration", "ScopeType", "TimeScaleDeclaration",
  "TimeScale", "TimeUnit", "VarDeclaration", "BitSelect", "VarType",
  "Size", "SimulationCommandList", "SimulationCommand", "ValueChangeset",
  "SimulationTime", "ValueChangeList", "ValueChange", "ScalarValueChange",
  "Value", "VectorValueChange", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-54)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-1)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int8 yypact[] =
{
      32,    -2,    56,    57,    37,   -17,    59,   -22,    60,    64,
      19,    32,   -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,
      62,     9,   -54,   -54,   -54,    65,    17,   -54,   -54,   -54,
     -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,
     -54,   -54,   -54,   -54,   -54,    66,    12,   -54,   -54,   -21,
     -21,   -21,   -21,    14,   -54,    19,   -54,   -21,   -54,   -54,
     -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,   -54,
     -54,    13,   -54,   -54,   -54,   -54,    18,    20,    71,   -21,
     -54,    21,   -54,    72,    73,    74,   -54,   -54,   -54,    22,
      24,    25,   -54,   -54,   -54,   -54,   -54,   -54,    -3,   -54,
     -54,    23,    29,   -54,   -53,    15,   -54,    30,   -54,    26,
     -54
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_int8 yydefact[] =
{
       3,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      52,     3,     5,     6,     7,    14,    15,    16,    18,    17,
       0,     0,    20,    21,    22,     0,     0,    10,    34,    35,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,     0,     0,    11,     1,    61,
      61,    61,    61,     0,     2,    52,    58,    61,     4,     8,
      13,     9,    27,    25,    26,    28,    23,    24,    19,    12,
      51,     0,    67,    69,    66,    68,     0,     0,     0,    61,
      63,     0,    64,     0,     0,     0,    60,    53,    59,     0,
       0,     0,    54,    62,    65,    55,    56,    57,    30,    70,
      71,     0,     0,    29,     0,     0,    31,     0,    33,     0,
      32
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int8 yypgoto[] =
{
     -54,   -54,    75,   -54,   -54,   -54,   -54,   -54,   -54,   -54,
     -54,   -54,   -54,    34,   -54,   -54,   -54,   -44,   -54,   -54,
     -54,   -54
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int8 yydefgoto[] =
{
       0,     9,    10,    11,    20,    21,    25,    26,    68,    45,
     103,    46,    71,    54,    55,    56,    57,    78,    79,    80,
      81,    82
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int8 yytable[] =
{
      72,    12,    73,    74,    22,    75,    83,    84,    85,   106,
     107,    23,    24,    88,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    49,    50,    51,    52,    93,     1,     2,     3,     4,
       5,     6,     7,     8,    53,    76,    77,    62,    63,    64,
      65,    66,    67,    15,    16,    17,    18,    19,   101,    13,
      14,   102,    27,    47,    48,    59,    60,    70,    61,    69,
      86,    89,    90,    91,    92,    95,    96,    97,   104,    94,
     108,    98,    99,   100,   105,   109,    58,     0,   110,    87
};

static const yytype_int8 yycheck[] =
{
      21,     3,    23,    24,    21,    26,    50,    51,    52,    62,
      63,    28,    29,    57,    36,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    48,    49,    50,    51,
      52,    12,    13,    14,    15,    79,     4,     5,     6,     7,
       8,     9,    10,    11,    25,    66,    67,    30,    31,    32,
      33,    34,    35,    16,    17,    18,    19,    20,    61,     3,
       3,    64,     3,     3,     0,     3,    57,    55,     3,     3,
      56,    58,    54,    53,     3,     3,     3,     3,    55,    58,
      65,    59,    58,    58,    55,    55,    11,    -1,    62,    55
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_int8 yystos[] =
{
       0,     4,     5,     6,     7,     8,     9,    10,    11,    69,
      70,    71,     3,     3,     3,    16,    17,    18,    19,    20,
      72,    73,    21,    28,    29,    74,    75,     3,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      48,    49,    50,    51,    52,    77,    79,     3,     0,    12,
      13,    14,    15,    25,    81,    82,    83,    84,    70,     3,
      57,     3,    30,    31,    32,    33,    34,    35,    76,     3,
      55,    80,    21,    23,    24,    26,    66,    67,    85,    86,
      87,    88,    89,    85,    85,    85,    56,    81,    85,    58,
      54,    53,     3,    85,    58,     3,     3,     3,    59,    58,
      58,    61,    64,    78,    55,    55,    62,    63,    65,    55,
      62
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr1[] =
{
       0,    68,    69,    70,    70,    71,    71,    71,    71,    71,
      71,    71,    71,    72,    73,    73,    73,    73,    73,    74,
      75,    75,    75,    76,    76,    76,    76,    76,    76,    77,
      78,    78,    78,    78,    79,    79,    79,    79,    79,    79,
      79,    79,    79,    79,    79,    79,    79,    79,    79,    79,
      79,    80,    81,    81,    82,    82,    82,    82,    82,    83,
      84,    85,    85,    86,    86,    87,    88,    88,    88,    88,
      89,    89
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     2,     0,     2,     2,     2,     2,     3,     3,
       2,     2,     3,     2,     1,     1,     1,     1,     1,     2,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     5,
       0,     3,     5,     3,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     0,     2,     3,     3,     3,     3,     1,     2,
       2,     0,     2,     1,     1,     2,     1,     1,     1,     1,
       3,     3
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = VCD_EMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == VCD_EMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use VCD_error or VCD_UNDEF. */
#define YYERRCODE VCD_UNDEF


/* Enable debugging if requested.  */
#if VCD_DEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)




# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  yy_symbol_value_print (yyo, yykind, yyvaluep);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp,
                 int yyrule)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)]);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !VCD_DEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !VCD_DEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif






/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
{
  YY_USE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/* Lookahead token kind.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;




/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = VCD_EMPTY; /* Cause a token to be read.  */

  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == VCD_EMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex ();
    }

  if (yychar <= VCD_EOF)
    {
      yychar = VCD_EOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == VCD_error)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = VCD_UNDEF;
      yytoken = YYSYMBOL_YYerror;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  /* Discard the shifted token.  */
  yychar = VCD_EMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 8: /* Declaration: t_SCOPE ScopeDeclaration t_END  */
#line 119 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                    {
     if (!vcd->scopes) {
       /* no scope defined yet */
       vcd->scopes = (struct vcd_scope *)
	 calloc (1, sizeof (struct vcd_scope));
       vcd->scopes->ident = strdup (VCD_NOSCOPE);
       vcd->scopes->scopes = (yyvsp[-1].scope);
       (yyvsp[-1].scope)->parent = vcd->scopes;
     } else {
       /* concatenate scope definitions */
       (yyvsp[-1].scope)->next = vcd->currentscope->scopes;
       vcd->currentscope->scopes = (yyvsp[-1].scope);
       (yyvsp[-1].scope)->parent = vcd->currentscope;
     }
     vcd->currentscope = (yyvsp[-1].scope);
   }
#line 1293 "parse_vcd.cpp"
    break;

  case 10: /* Declaration: t_UPSCOPE t_END  */
#line 136 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                     {
     if (vcd->currentscope->parent) {
       /* up one scope */
       vcd->currentscope = vcd->currentscope->parent;
     } else {
       fprintf (stderr, "vcd notice, unnecessary $upscope in line %d\n",
		vcd_lineno);
     }
   }
#line 1307 "parse_vcd.cpp"
    break;

  case 12: /* Declaration: t_VAR VarDeclaration t_END  */
#line 146 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                {
     if (!vcd->scopes) {
       /* no scope defined yet */
       vcd->scopes = (struct vcd_scope *)
	 calloc (1, sizeof (struct vcd_scope));
       vcd->scopes->ident = strdup (VCD_NOSCOPE);
       vcd->currentscope = vcd->scopes;
     }
     /* concatenate variable definitions */
     (yyvsp[-1].vardef)->scope = vcd->currentscope;
     (yyvsp[-1].vardef)->next = vcd->currentscope->vardefs;
     vcd->currentscope->vardefs = (yyvsp[-1].vardef);
   }
#line 1325 "parse_vcd.cpp"
    break;

  case 13: /* ScopeDeclaration: ScopeType Identifier  */
#line 162 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                        {
     (yyval.scope) = (struct vcd_scope *) calloc (1, sizeof (struct vcd_scope));
     (yyval.scope)->type = (yyvsp[-1].stype);
     (yyval.scope)->ident = (yyvsp[0].ident);
   }
#line 1335 "parse_vcd.cpp"
    break;

  case 14: /* ScopeType: s_MODULE  */
#line 170 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.stype) = SCOPE_MODULE;   }
#line 1341 "parse_vcd.cpp"
    break;

  case 15: /* ScopeType: s_TASK  */
#line 171 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.stype) = SCOPE_TASK;     }
#line 1347 "parse_vcd.cpp"
    break;

  case 16: /* ScopeType: s_FUNCTION  */
#line 172 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.stype) = SCOPE_FUNCTION; }
#line 1353 "parse_vcd.cpp"
    break;

  case 17: /* ScopeType: s_BEGIN  */
#line 173 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.stype) = SCOPE_BEGIN;    }
#line 1359 "parse_vcd.cpp"
    break;

  case 18: /* ScopeType: s_FORK  */
#line 174 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.stype) = SCOPE_FORK;     }
#line 1365 "parse_vcd.cpp"
    break;

  case 19: /* TimeScaleDeclaration: TimeScale TimeUnit  */
#line 178 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                      {
     vcd->t = (yyvsp[-1].integer);
     vcd->scale = (yyvsp[0].real);
   }
#line 1374 "parse_vcd.cpp"
    break;

  case 20: /* TimeScale: ONE  */
#line 185 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.integer) = 1;   }
#line 1380 "parse_vcd.cpp"
    break;

  case 21: /* TimeScale: TEN  */
#line 186 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.integer) = 10;  }
#line 1386 "parse_vcd.cpp"
    break;

  case 22: /* TimeScale: HUNDRET  */
#line 187 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.integer) = 100; }
#line 1392 "parse_vcd.cpp"
    break;

  case 23: /* TimeUnit: SECOND  */
#line 191 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
            { (yyval.real) = 1;     }
#line 1398 "parse_vcd.cpp"
    break;

  case 24: /* TimeUnit: MILLI  */
#line 192 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
            { (yyval.real) = 1e-3;  }
#line 1404 "parse_vcd.cpp"
    break;

  case 25: /* TimeUnit: MICRO  */
#line 193 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
            { (yyval.real) = 1e-6;  }
#line 1410 "parse_vcd.cpp"
    break;

  case 26: /* TimeUnit: NANO  */
#line 194 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
            { (yyval.real) = 1e-9;  }
#line 1416 "parse_vcd.cpp"
    break;

  case 27: /* TimeUnit: PICO  */
#line 195 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
            { (yyval.real) = 1e-12; }
#line 1422 "parse_vcd.cpp"
    break;

  case 28: /* TimeUnit: FEMTO  */
#line 196 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
            { (yyval.real) = 1e-15; }
#line 1428 "parse_vcd.cpp"
    break;

  case 29: /* VarDeclaration: VarType Size IdentifierCode Reference BitSelect  */
#line 200 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                                   {
     (yyval.vardef) = (struct vcd_vardef *) calloc (1, sizeof (struct vcd_vardef));
     (yyval.vardef)->type = (yyvsp[-4].vtype);
     (yyval.vardef)->size = (yyvsp[-3].integer);
     (yyval.vardef)->code = (yyvsp[-2].ident);
     (yyval.vardef)->ident = (yyvsp[-1].ident);
     (yyval.vardef)->range = (yyvsp[0].range);
   }
#line 1441 "parse_vcd.cpp"
    break;

  case 30: /* BitSelect: %empty  */
#line 210 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                         { (yyval.range) = NULL; }
#line 1447 "parse_vcd.cpp"
    break;

  case 31: /* BitSelect: '[' PositiveInteger ']'  */
#line 211 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                              {
      (yyval.range) = (struct vcd_range *) calloc (1, sizeof (struct vcd_range));
      (yyval.range)->l = -1;
      (yyval.range)->h = (yyvsp[-1].integer);
    }
#line 1457 "parse_vcd.cpp"
    break;

  case 32: /* BitSelect: '[' PositiveInteger ':' PositiveInteger ']'  */
#line 216 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                                  {
      (yyval.range) = (struct vcd_range *) calloc (1, sizeof (struct vcd_range));
      (yyval.range)->l = (yyvsp[-3].integer);
      (yyval.range)->h = (yyvsp[-1].integer);
    }
#line 1467 "parse_vcd.cpp"
    break;

  case 33: /* BitSelect: '(' PositiveInteger ')'  */
#line 221 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                              {
      (yyval.range) = (struct vcd_range *) calloc (1, sizeof (struct vcd_range));
      (yyval.range)->l = (yyvsp[-1].integer);
      (yyval.range)->h = -1;
    }
#line 1477 "parse_vcd.cpp"
    break;

  case 34: /* VarType: EVENT  */
#line 229 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_EVENT;
     /* a special type to synchronize different statement blocks */ }
#line 1484 "parse_vcd.cpp"
    break;

  case 35: /* VarType: INTEGER  */
#line 231 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_INTEGER;
     /* signed 32-bit variable */ }
#line 1491 "parse_vcd.cpp"
    break;

  case 36: /* VarType: PARAMETER  */
#line 233 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_PARAMETER;
     /* a named constant - the default value of a parameter can be
	overwritten, when declaring an instance of the associated module */ }
#line 1499 "parse_vcd.cpp"
    break;

  case 37: /* VarType: REAL  */
#line 236 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_REAL;
     /* double-precision floating point */ }
#line 1506 "parse_vcd.cpp"
    break;

  case 38: /* VarType: REG  */
#line 238 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_REG;
     /* unsigned variable of any bit size */ }
#line 1513 "parse_vcd.cpp"
    break;

  case 39: /* VarType: SUPPLY0  */
#line 240 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_SUPPLY0;
     /* constant logic 0 (supply strength) */ }
#line 1520 "parse_vcd.cpp"
    break;

  case 40: /* VarType: SUPPLY1  */
#line 242 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_SUPPLY1;
     /* constant logic 1 (supply strength) */ }
#line 1527 "parse_vcd.cpp"
    break;

  case 41: /* VarType: TIME  */
#line 244 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TIME;
     /* unsigned 64-bit variable */ }
#line 1534 "parse_vcd.cpp"
    break;

  case 42: /* VarType: TRI  */
#line 246 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TRI;
     /* simple interconnecting wire */ }
#line 1541 "parse_vcd.cpp"
    break;

  case 43: /* VarType: TRIAND  */
#line 248 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TRIAND;
     /* wired outputs AND together */ }
#line 1548 "parse_vcd.cpp"
    break;

  case 44: /* VarType: TRIOR  */
#line 250 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TRIOR;
     /* wired outputs OR together */ }
#line 1555 "parse_vcd.cpp"
    break;

  case 45: /* VarType: TRIREG  */
#line 252 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TRIREG;
     /* stores last value when tri-stated (capacitance strength) */ }
#line 1562 "parse_vcd.cpp"
    break;

  case 46: /* VarType: TRI0  */
#line 254 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TRI0;
     /* pulls down when tri-stated */ }
#line 1569 "parse_vcd.cpp"
    break;

  case 47: /* VarType: TRI1  */
#line 256 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_TRI1;
     /* pulls up when tri-stated */ }
#line 1576 "parse_vcd.cpp"
    break;

  case 48: /* VarType: WAND  */
#line 258 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_WAND;
     /* wired outputs AND together */ }
#line 1583 "parse_vcd.cpp"
    break;

  case 49: /* VarType: WIRE  */
#line 260 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_WIRE;
     /* simple interconnecting wire */ }
#line 1590 "parse_vcd.cpp"
    break;

  case 50: /* VarType: WOR  */
#line 262 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
               { (yyval.vtype) = VAR_WOR;
     /* wired outputs OR together */ }
#line 1597 "parse_vcd.cpp"
    break;

  case 57: /* SimulationCommand: t_DUMPVARS ValueChangeList t_END  */
#line 278 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                     {
      vcd->changesets->changes = (yyvsp[-1].change);
  }
#line 1605 "parse_vcd.cpp"
    break;

  case 58: /* SimulationCommand: ValueChangeset  */
#line 281 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                   {
      (yyvsp[0].changeset)->next = vcd->changesets;
      vcd->changesets = (yyvsp[0].changeset);
  }
#line 1614 "parse_vcd.cpp"
    break;

  case 59: /* ValueChangeset: SimulationTime ValueChangeList  */
#line 288 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                   {
      (yyval.changeset) = (struct vcd_changeset *) calloc (1, sizeof (struct vcd_changeset));
      (yyval.changeset)->t = (yyvsp[-1].real);
      (yyval.changeset)->changes = (yyvsp[0].change);
    }
#line 1624 "parse_vcd.cpp"
    break;

  case 60: /* SimulationTime: HASHMARK PositiveHugeInteger  */
#line 296 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                 {
      (yyval.real) = (yyvsp[0].real);
    }
#line 1632 "parse_vcd.cpp"
    break;

  case 61: /* ValueChangeList: %empty  */
#line 301 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                               { (yyval.change) = NULL; }
#line 1638 "parse_vcd.cpp"
    break;

  case 62: /* ValueChangeList: ValueChange ValueChangeList  */
#line 302 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                  {
      (yyvsp[-1].change)->next = (yyvsp[0].change);
    }
#line 1646 "parse_vcd.cpp"
    break;

  case 65: /* ScalarValueChange: Value IdentifierCode  */
#line 313 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                         {
      (yyval.change) = (struct vcd_change *) calloc (1, sizeof (struct vcd_change));
      (yyval.change)->value = (yyvsp[-1].value);
      (yyval.change)->code = (yyvsp[0].ident);
    }
#line 1656 "parse_vcd.cpp"
    break;

  case 70: /* VectorValueChange: 'B' Binary IdentifierCode  */
#line 328 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                              {
      (yyval.change) = (struct vcd_change *) calloc (1, sizeof (struct vcd_change));
      (yyval.change)->value = (yyvsp[-1].value);
      (yyval.change)->code = (yyvsp[0].ident);
    }
#line 1666 "parse_vcd.cpp"
    break;

  case 71: /* VectorValueChange: 'R' Real IdentifierCode  */
#line 333 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                              {
      (yyval.change) = (struct vcd_change *) calloc (1, sizeof (struct vcd_change));
      (yyval.change)->value = (yyvsp[-1].value);
      (yyval.change)->code = (yyvsp[0].ident);
      (yyval.change)->isreal = 1;
    }
#line 1677 "parse_vcd.cpp"
    break;


#line 1681 "parse_vcd.cpp"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == VCD_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      yyerror (YY_("syntax error"));
    }

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= VCD_EOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == VCD_EOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = VCD_EMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != VCD_EMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif

  return yyresult;
}

#line 342 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"


int vcd_error (const char * error) {
  fprintf (stderr, "line %d: %s\n", vcd_lineno, error);
  return 0;
}
